@@ -1,15 +1,17 @@
 # SPDX-FileCopyrightText: 2017-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
+from __future__ import annotations
 
 import sys
-from collections.abc import Mapping, Sequence  # noqa: F401
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Any
 
 
 if TYPE_CHECKING:
-    from .handler import ListenerModuleHandler  # noqa: F401
-    from .handler_configuration import ListenerModuleConfiguration  # noqa: F401
+    from collections.abc import Mapping, Sequence
+
+    from .handler import ListenerModuleHandler
+    from .handler_configuration import ListenerModuleConfiguration
 
 
 class ListenerModuleAdapter:
@@ -19,34 +21,31 @@ class ListenerModuleAdapter:
 
     Use in a classic listener module like this:
 
-            globals().update(ListenerModuleAdapter(MyListenerModuleConfiguration()).get_globals())
+        globals().update(ListenerModuleAdapter(MyListenerModuleConfiguration()).get_globals())
     """
 
-    def __init__(self, module_configuration, *args, **kwargs):
-        # type: (ListenerModuleConfiguration, *Any, **Any) -> None
+    def __init__(self, module_configuration: ListenerModuleConfiguration, *args: Any, **kwargs: Any) -> None:
         """:param ListenerModuleConfiguration module_configuration: configuration object"""
         self.config = module_configuration
-        self._ldap_cred = {}  # type: Dict[str, str]
-        self._module_handler_obj = None  # type: Optional[ListenerModuleHandler]
-        self._saved_old = {}  # type: Mapping[str, Sequence[bytes]]
-        self._saved_old_dn = None  # type: Optional[str]
+        self._ldap_cred: dict[str, str] = {}
+        self._module_handler_obj: ListenerModuleHandler | None = None
+        self._saved_old: Mapping[str, Sequence[bytes]] = {}
+        self._saved_old_dn: str | None = None
         self._rename = False
         self._renamed = False
         self._run_checks()
 
-    def _run_checks(self):
-        # type: () -> None
+    def _run_checks(self) -> None:
         pass
 
-    def get_globals(self):
-        # type: () -> Dict[str, Any]
+    def get_globals(self) -> dict[str, Any]:
         """
         Returns the variables to be written to the module namespace, that
         make up the legacy listener module interface.
 
         :return: a mapping with keys: `name`, `description`, `filter_s`,
-                `attributes`, `modrdn`, `handler`, `initialize`, `clean`, `prerun`,
-                `postrun`, `setdata`, ..
+            `attributes`, `modrdn`, `handler`, `initialize`, `clean`, `prerun`,
+            `postrun`, `setdata`, ..
         :rtype: dict
         """
         name = self.config.get_name()
@@ -76,8 +75,7 @@ class ListenerModuleAdapter:
             "setdata": setdata,
         }
 
-    def _setdata(self, key, value):
-        # type: (str, str) -> None
+    def _setdata(self, key: str, value: str) -> None:
         """
         Store LDAP connection credentials passes by the listener (one by one)
         to the listener module. Passes them to the handler object once they
@@ -97,15 +95,13 @@ class ListenerModuleAdapter:
             self._ldap_cred.clear()
 
     @property
-    def _module_handler(self):
-        # type: () -> ListenerModuleHandler
+    def _module_handler(self) -> ListenerModuleHandler:
         """Make sure to not create more than one instance of a listener module."""
         if not self._module_handler_obj:
             self._module_handler_obj = self.config.get_listener_module_instance()
         return self._module_handler_obj
 
-    def _handler(self, dn, new, old, command):
-        # type: (str, Mapping[str, Sequence[bytes]], Mapping[str, Sequence[bytes]], str) -> None
+    def _handler(self, dn: str, new: Mapping[str, Sequence[bytes]], old: Mapping[str, Sequence[bytes]], command: str) -> None:
         """
         Function called by listener when a LDAP object matching the filter is
         created/modified/moved/deleted.
@@ -143,18 +139,14 @@ class ListenerModuleAdapter:
             exc_type, exc_value, exc_traceback = sys.exc_info()
             self._module_handler.error_handler(dn, old, new, command, exc_type, exc_value, exc_traceback)
 
-    def _lazy_initialize(self):
-        # type: () -> None
+    def _lazy_initialize(self) -> None:
         return self._module_handler.initialize()
 
-    def _lazy_clean(self):
-        # type: () -> None
+    def _lazy_clean(self) -> None:
         return self._module_handler.clean()
 
-    def _lazy_pre_run(self):
-        # type: () -> None
+    def _lazy_pre_run(self) -> None:
         return self._module_handler.pre_run()
 
-    def _lazy_post_run(self):
-        # type: () -> None
+    def _lazy_post_run(self) -> None:
         return self._module_handler.post_run()
