@@ -2,35 +2,8 @@
  * Univention Directory Listener
  *  entries in the cache
  *
- * Like what you see? Join us!
- * https://www.univention.com/about-us/careers/vacancies/
- *
- * Copyright 2004-2024 Univention GmbH
- *
- * https://www.univention.de/
- *
- * All rights reserved.
- *
- * The source code of this program is made available
- * under the terms of the GNU Affero General Public License version 3
- * (GNU AGPL V3) as published by the Free Software Foundation.
- *
- * Binary versions of this program provided by Univention to you as
- * well as other copyrighted, protected or trademarked materials like
- * Logos, graphics, fonts, specific documentations and configurations,
- * cryptographic keys etc. are subject to a license agreement between
- * you and Univention and not subject to the GNU AGPL V3.
- *
- * In the case you use this program under the terms of the GNU AGPL V3,
- * the program is provided in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public
- * License with the Debian GNU/Linux or Univention distribution in file
- * /usr/share/common-licenses/AGPL-3; if not, see
- * <https://www.gnu.org/licenses/>.
+ * SPDX-FileCopyrightText: 2004-2025 Univention GmbH
+ * SPDX-License-Identifier: AGPL-3.0-only
  */
 
 #include <stdlib.h>
@@ -519,7 +492,7 @@ static CacheEntryAttribute *_cache_entry_add_new_attribute(CacheEntry *entry, LD
 	entry->attributes = tmp;
 
 	BER2STR(&ava->la_attr, &attr->name);
-	if (!&attr->name) {
+	if (!attr->name) {
 		univention_debug(UV_DEBUG_LISTENER, UV_DEBUG_ERROR, "%s:%d BER2STR() failed", __FILE__, __LINE__);
 		goto error;
 	}
